@@ -37,14 +37,15 @@
 #'}
 
 'costrasterGen' <- function(xymat, pols, extent = "polys", projstr){
-  
-  if(class(xymat) == "SpatialPointsDataFrame" | class(xymat) == "SpatialPoints"){
+  if(class(xymat) == "SpatialPointsDataFrame" |
+  	 class(xymat) == "SpatialPoints"){
     xymat <- coordinates(xymat)
   }
   
   #add check to see if projstr and projection(pols) match
   if(!identical(projstr, sp::proj4string(pols))){
-    message("Warning, the projection of polygons does not match projstr. See rgdal::spTransform")
+    message("Warning, the projection of polygons does not
+    				match projstr. See rgdal::spTransform")
   }
   
   #define spatial domain based on pnts or polys
@@ -66,7 +67,8 @@
   ncol <- xmx - xmn
   
   #generate cost raster
-  r <- raster::raster(nrow = nrow, ncol = ncol, crs = projstr, xmn = xmn, xmx = xmx, ymn = ymn, ymx = ymx)
+  r <- raster::raster(nrow = nrow, ncol = ncol, crs = projstr, xmn = xmn,
+  										xmx = xmx, ymn = ymn, ymx = ymx)
   costras <- raster::rasterize(pols, r, silent = TRUE)
   m <- c(0, +Inf, 10000)
   rclmat <- matrix(m, ncol = 3, byrow = TRUE)
@@ -75,4 +77,3 @@
   
   return(costras)  
 }
-
