@@ -26,18 +26,21 @@
 #'@examples
 #' #see vignette
 
-'ipdw' <- function(spdf, costras, range, paramlist, overlapped = FALSE, yearmon = "default", removefile = TRUE, step = 16){
+'ipdw' <- function(spdf, costras, range, paramlist, overlapped = FALSE,
+					yearmon = "default", removefile = TRUE, step = 16){
   
   if(!identical(projection(spdf), projection(costras))){
-    stop("Point data projection and cost raster projections do not match, see rgdal::spTransform")
+    stop("Point data projection and cost raster projections do not match,
+    		 see rgdal::spTransform")
   }
   
   #pathdistGen
   pathdists <- pathdistGen(spdf, costras, range, step)
   
   #ipdwInterp
-  final.ipdw <- ipdwInterp(spdf, pathdists, paramlist, yearmon, removefile = TRUE, overlapped = overlapped)
+  final.ipdw <- ipdwInterp(spdf, pathdists, paramlist, yearmon,
+  							removefile = TRUE, overlapped = overlapped)
   
   return(final.ipdw)  
   
-}
\ No newline at end of file
+}
